# Copyright (C) 2021 Elliot Killick <elliotkillick@zohomail.eu>
# Licensed under the MIT License. See LICENSE file for details.

%define vm_name qubes-video-companion

Name:           %{vm_name}-dom0
Version:        1.0.7
Release:        1%{?dist}
Summary:        Securely stream webcams and share screens across virtual machines

License:        MIT
URL:            https://github.com/elliotkillick/qubes-video-companion
Source0:        %{vm_name}-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  make
BuildRequires:  python3-setuptools
BuildRequires:  python3-devel

Requires:       gstreamer1-plugins-good

%description
Qubes Video Companion is a tool for securely streaming webcams and sharing
screens across virtual machines.

It accomplishes this by creating a uni-directional flow of raw video that is
passed from one virtual machine to another through file descriptors thereby
allowing both machines to be completely air-gaped with no networking stacks
exposed. This design makes the side of the video sending virtual machine 100%
immune to attack and only leaves a very small attack surface on the side of
the video receiving virtual machine.

The project emphasizes correctness and security all the while also sporting
superb performance by maintaining a small footprint of the available
computational resources and low latency even at Full HD and greater
resolutions at 30 or more frames per second.

This package contains only the video senders, Qubes RPC policies and
associated documentation components of Qubes Video Companion which are
necessary for dom0.

%prep
%autosetup -n %{vm_name}-%{version}

%build
# Enable Python 3 for Qubes R4.0 dom0 (Fedora 25) support because it defaults to Python 2
%define  __python %{__pythonX}
%make_build

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=%{?buildroot} install-dom0 install-license

%files
%{_licensedir}/qubes-video-companion/LICENSE
%{_docdir}/qubes-video-companion/README.md
%{_docdir}/qubes-video-companion/pipeline.md
%{_docdir}/qubes-video-companion/visualizations/*
%{_sysconfdir}/qubes-rpc/qvc.Webcam
%{_sysconfdir}/qubes-rpc/qvc.ScreenShare
%{_sysconfdir}/qubes-rpc/policy/qvc.Webcam
%{_sysconfdir}/qubes-rpc/policy/qvc.ScreenShare
%{_datadir}/qubes-video-companion/sender/service.py
%{_datadir}/qubes-video-companion/sender/webcam.py
%{_datadir}/qubes-video-companion/sender/screenshare.py
%{_datadir}/qubes-video-companion/sender/tray_icon.py
%{python3_sitelib}/qvctests
%{python3_sitelib}/qvctests-*.egg-info

%changelog
* Sun Apr 28 2024 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-video-companion.git

* Sun Apr 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6246500
- version 1.0.7-1

* Thu Apr 25 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8d8b391
- Downgrade v4l2loopback-dkms dependency to "Suggests"

* Thu Apr 25 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1d1b452
- Remove "WIP" disclaimer

* Tue Apr 16 2024 Atrate <Atrate@protonmail.com> - 1205c79
- Fix installation instructions

* Fri Mar 29 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 5462c6d
- Allow the receiver to request a preferred resolution

* Fri Mar 29 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 07038c6
- version 1.0.6-1

* Fri Mar 29 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8358cf3
- tests: check if the source /dev/video0 works before testing webcam

* Thu Mar 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2468c1e
- Skip building v4l2loopback dkms module on qubes kernel

* Thu Mar 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 266e229
- debian: add missing dependencies

* Thu Mar 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fd1e5ee
- Call modinfo via sudo too

* Thu Mar 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 73f4219
- tests: print more details if the main process exit early

* Thu Mar 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f7cf09d
- tests: make error message a bit more informative

* Thu Mar 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c556e6b
- tests: use gst on both sides of the connection

* Fri Mar 15 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8e04635
- tests: fix waiting for streaming start

* Tue Oct 24 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 254bda6
- version 1.0.5-1

* Tue Oct 24 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f209687
- rpm: produce base qubes-video-companion package

* Sat Oct 21 2023 Tim <timdev21@users.noreply.github.com> - 37f9acb
- fix setfacl command

* Mon Oct 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b7cf38c
- version 1.0.4-1

* Mon Sep 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 9414a90
- Use literals instead of function calls

* Mon Sep 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - da66f39
- Add missing 'acl' dependency

* Sat Aug 19 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5fc9e5b
- Fix issues found by pylint

* Sat Aug 19 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5091239
- Update pylint config

* Sat Aug 19 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3f7bd65
- ci: install pylint too

* Sat Aug 19 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - d6b5c77
- Avoid hardcoding user "user"

* Fri Jul 28 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a072218
- version 1.0.3-1

* Mon Jul 17 2023 WillyJL <49810075+Willy-JL@users.noreply.github.com> - 763744e
- Use kwargs instead of querying geometry twice

* Wed Jul 12 2023 WillyJL <49810075+Willy-JL@users.noreply.github.com> - fe863dd
- Fix screenshare with multiple monitors

* Tue Mar 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8313497
- version 1.0.2-1

* Tue Mar 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3021f41
- debian: only recommend v4l2loopback-dkms

* Tue Mar 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1787d9f
- Fix typing hints

* Mon Jan 16 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7b568f1
- version 1.0.1-1

* Sun Jan 15 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 313ce9b
- pylint: disable consider-using-f-string

* Thu Jan 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 038b4f8
- tests: webcam test is supposed to work now

* Thu Jan 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ce725b8
- webcam: workaround gstreamer bug for video/x-raw source

* Thu Jan 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 741a487
- Drop --buffer-size=0, it doesn't do anything

* Thu Jan 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - dd8e6be
- tests: log more details on failure

* Thu Jan 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9bb6481
- sender/webcam: support raw source stream too

* Wed Jan 11 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9dafa4e
- Remove 'colorimetry' pipeline constraint

* Sun Sep 18 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b3706f8
- ci: limit pylint to actual package

* Sun Sep 18 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cb91413
- tests: add skeleton for webcam test too

* Sun Sep 18 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 14b44ce
- tests: add basic integration test for screen share

* Wed Jul 13 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f710822
- Add v4l-utils dependency

* Mon Jun 20 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 82c1038
- Make pylint happy again

* Mon Jun 20 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 683e401
- Reformat code according to python-black

* Mon Jun 20 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 240c140
- Make pylint happy

* Mon Jun 20 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 7800118
- Add .pylintrc from core-admin and fix deps

* Sat Jun 18 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 58cf260
- Make shellcheck happy

* Sat Jun 18 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a790ea9
- Qubes Builder integration

* Sat Jun 18 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 51f9c35
- Rework .gitlab-ci.yml

* Tue Apr 12 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - c7215ba
- Allow @default in the qrexec policies

